@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
+
 """
     PyLucid unittests
     ~~~~~~~~~~~~~~~~~
@@ -10,12 +11,14 @@
         - There exist only "PyLucid CMS" blog entry in english and german
         
     TODO:
+        * Rewrite tests if we use django-compressor
         * Test clone colorscheme in admin
     
-    :copyleft: 2010 by the PyLucid team, see AUTHORS for more details.
+    :copyleft: 2010-2011 by the PyLucid team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+
 import os
 
 if __name__ == "__main__":
@@ -114,11 +117,15 @@ class CloneDesignTest(basetest.BaseUnittest, TestCase):
 
     def test_request_form(self):
         response = self.client.get(self.url)
+        self.assertDOM(response,
+            must_contain=(
+                '<input id="id_new_name" name="new_name" type="text" />',
+            )
+        )
         self.assertResponse(response,
             must_contain=(
                 "Clone a existing page design",
-                '<input id="id_new_name" name="new_name" type="text" />',
-                '<select id="id_design" name="design">',
+                '<select', 'id="id_design"', 'name="design"',
                 "clone design",
             ),
             must_not_contain=("Traceback",)
@@ -138,11 +145,15 @@ class CloneDesignTest(basetest.BaseUnittest, TestCase):
         self.assertRedirect(response, url=new_url, status_code=302)
 
         response = self.client.get(new_url)
+        self.assertDOM(response,
+            must_contain=(
+                '<input id="id_new_name" name="new_name" type="text" />',
+            )
+        )
         self.assertResponse(response,
             must_contain=(
                 "Clone a existing page design",
-                '<input id="id_new_name" name="new_name" type="text" />',
-                '<select id="id_design" name="design">',
+                '<select', 'id="id_design"', 'name="design"',
                 "clone design",
                 "New design &#39;%s&#39; created." % new_name,
             ),
@@ -213,8 +224,8 @@ class FixtureDataDesignTest(BaseTestCase, TestCase):
         self.design3 = Design.objects.get(name="inverted blue")
         self.design4 = Design.objects.get(name="inverted yellow")
 
-        self.test_css_url1 = "/media/PyLucid/headfile_cache/ColorScheme_1/test_styles.css"
-        self.test_css_url2 = "/media/PyLucid/headfile_cache/ColorScheme_2/test_styles.css"
+        self.test_css_url1 = "/media/PyLucid_cache/ColorScheme_1/test_styles.css"
+        self.test_css_url2 = "/media/PyLucid_cache/ColorScheme_2/test_styles.css"
 
     def setUp(self):
         removed_items = EditableHtmlHeadFile.objects.clean_headfile_cache()
@@ -232,8 +243,11 @@ class FixtureDataDesignTest(BaseTestCase, TestCase):
         headfile = design.headfiles.all()[0]
         colorscheme = design.colorscheme
         url = headfile.get_absolute_url(colorscheme)
-        self.assertTrue("/headfile_cache/" in url)
+        self.assertTrue("/PyLucid_cache/" in url)
         response = self.client.get(url)
+        self.assertResponse(response,
+            must_not_contain=("<head>", "<title>", "</body>", "</html>")
+        )
         return response
 
     def check_styles(self):
@@ -254,14 +268,14 @@ class FixtureDataDesignTest(BaseTestCase, TestCase):
         self.headfile1.content = "one"
         self.headfile1.save()
         url = self.headfile1.get_absolute_url()
-        self.assertTrue("/headfile_cache/" in url)
+        self.assertTrue("/PyLucid_cache/" in url)
         response = self.client.get(url)
         self.assertEqual(response.content, "one")
 
         self.headfile1.content = "two"
         self.headfile1.save()
         url = self.headfile1.get_absolute_url()
-        self.assertTrue("/headfile_cache/" in url)
+        self.assertTrue("/PyLucid_cache/" in url)
         response = self.client.get(url)
         self.assertEqual(response.content, "two")
 
@@ -485,20 +499,22 @@ class FixtureDataDesignTest(BaseTestCase, TestCase):
             url="http://testserver" + self.url_edit_colorscheme1
         )
         response = self.client.get(self.url_edit_colorscheme1)
+        self.assertDOM(response,
+            must_contain=(
+                # colorscheme name:
+                '<input name="name" value="yellow" class="vTextField" maxlength="255" type="text" id="id_name" />',
+                #colors:
+                '<input name="color_set-0-name" value="background" class="vTextField" maxlength="128" type="text" id="id_color_set-0-name" />',
+                '<input style="background-ColorValue:#222200;" name="color_set-0-value" value="222200" maxlength="6" type="text" id="id_color_set-0-value" />',
+                '<input name="color_set-0-name" value="background" class="vTextField" maxlength="128" type="text" id="id_color_set-0-name" />',
+                '<input style="background-ColorValue:#0000ff;" name="color_set-1-value" value="0000ff" maxlength="6" type="text" id="id_color_set-1-value" />',
+            )
+        )
         self.assertResponse(response,
             must_contain=(
                 '<title>PyLucid - Change color scheme</title>',
                 'colorpicker.css', 'colorpicker.js',
                 'Change color scheme',
-
-                # colorscheme name:
-                'name="name" type="text" value="yellow" />',
-
-                # colors:
-                'name="color_set-0-name" type="text" value="background" />',
-                'name="color_set-0-value" style="background-ColorValue:#222200;" type="text" value="222200" />',
-                'name="color_set-1-name" type="text" value="foreground" />',
-                'name="color_set-1-value" style="background-ColorValue:#0000ff;" type="text" value="0000ff" />',
             ),
             must_not_contain=("Traceback", "This field is required.")
         )
@@ -680,11 +696,11 @@ class FixtureDataDesignTest(BaseTestCase, TestCase):
 
 if __name__ == "__main__":
     # Run all unittest directly
-#    management.call_command('test', "pylucid_plugins.design.tests.SwitchDesignTest",
-#        verbosity=2,
-#        failfast=True
-#    )
-    management.call_command('test', __file__,
+
+    tests = __file__
+#    tests = "pylucid_plugins.design.tests.SwitchDesignTest"
+
+    management.call_command('test', tests,
         verbosity=2,
         failfast=True
     )
